Package 'OpenSourceAP.DownloadR'
| Title: |
Download Open Source Asset Pricing (OpenAP) Data Directly |
| Description: |
Convenient download functions enabling access Open Source
Asset Pricing (OpenAP) data. This package enables users to
download predictor portfolio returns (over 200 cross-sectional
predictors with multiple portfolio construction methods) and
firm characteristics (over 200 characteristics replicated from
the academic asset pricing literature). Center for Research in
Security Prices (CRSP)-based variables such as Price, Size, and
Short-term Reversal can be downloaded with a Wharton Research
Data Services (WRDS, <https://wrds-www.wharton.upenn.edu/>)
subscription. For a full list of what is available, see
<https://www.openassetpricing.com/>. |
| Authors: |
Tom Zimmermann [aut, cre] (ORCID:
<https://orcid.org/0000-0002-0368-5303>), Justus Boeker [ctb] |
| Maintainer: |
Tom Zimmermann <[email protected]> |
| License: |
MIT + file LICENSE |
| Version: |
0.1.0 |
| Built: |
2026-05-18 06:55:14 UTC |
| Source: |
https://github.com/cran/OpenSourceAP.DownloadR |
Help Index